@@ -1,9 +1,10 @@
-import gradio as gr
-from gradio import flagging
 import tempfile
 import unittest
 import unittest.mock as mock
 
+import gradio as gr
+from gradio import flagging
+
 
 class TestFlagging(unittest.TestCase):
     def test_default_flagging_handler(self):
@@ -18,7 +19,13 @@ class TestFlagging(unittest.TestCase):
 
     def test_simple_csv_flagging_handler(self):
         with tempfile.TemporaryDirectory() as tmpdirname:
-            io = gr.Interface(lambda x: x, "text", "text", flagging_dir=tmpdirname, flagging_callback=flagging.SimpleCSVLogger())
+            io = gr.Interface(
+                lambda x: x,
+                "text",
+                "text",
+                flagging_dir=tmpdirname,
+                flagging_callback=flagging.SimpleCSVLogger(),
+            )
             io.launch(prevent_thread_lock=True)
             row_count = io.flagging_callback.flag(io, ["test"], ["test"])
             self.assertEqual(row_count, 0)  # no header
@@ -27,5 +34,5 @@ class TestFlagging(unittest.TestCase):
         io.close()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
